Struct Route
pub struct Route { /* private fields */ }Expand description
One named route declaration.
Route names are the public labels matched against dose events such as iv
or oral.
Implementations
impl Route
impl Route
pub fn new(name: impl Into<String>, kind: RouteKind) -> Route
pub fn new(name: impl Into<String>, kind: RouteKind) -> Route
Create a route declaration with an explicit kind.
pub fn to_state(self, destination: impl Into<String>) -> Route
pub fn to_state(self, destination: impl Into<String>) -> Route
Declare which state this route targets.
pub fn with_bioavailability(self) -> Route
pub fn with_bioavailability(self) -> Route
Mark this route as supporting bioavailability handling.
pub fn inject_input_to_destination(self) -> Route
pub fn inject_input_to_destination(self) -> Route
Request direct injection into the destination state at execution time.
pub fn expect_explicit_input(self) -> Route
pub fn expect_explicit_input(self) -> Route
Request an explicit low-level input vector at execution time.
pub fn name(&self) -> &str
pub fn kind(&self) -> RouteKind
pub fn destination(&self) -> Option<&str>
pub fn has_lag(&self) -> bool
pub fn has_bioavailability(&self) -> bool
pub fn input_policy(&self) -> Option<RouteInputPolicy>