Struct ValidatedRoute
pub struct ValidatedRoute { /* private fields */ }Expand description
One validated route declaration with resolved execution details.
A validated route keeps both the declaration-order index and the dense input index used during execution. Those values can differ from each other when a model mixes bolus and infusion routes.
Implementations
impl ValidatedRoute
impl ValidatedRoute
pub fn kind(&self) -> RouteKind
pub fn declaration_index(&self) -> usize
pub fn declaration_index(&self) -> usize
Get the declaration-order index for this route.
pub fn input_index(&self) -> usize
pub fn input_index(&self) -> usize
Get the dense execution input index for this route kind.
pub fn destination(&self) -> &str
pub fn destination(&self) -> &str
Get the destination state name.
pub fn destination_index(&self) -> usize
pub fn destination_index(&self) -> usize
Get the destination state index in model order.
pub fn has_lag(&self) -> bool
pub fn has_bioavailability(&self) -> bool
pub fn input_policy(&self) -> Option<RouteInputPolicy>